
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.30.0rc3',
    'branch_nick': 'master',
    'revision_id': '3b06e7d689f561b442e56728f45dc44e35b007e7',
    'revno': 12314
}
